﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Diagnostics;
using System.Threading;
using System.IO;
using System.Windows;
using System.Threading.Tasks;
using System.Windows.Threading;

namespace PythonScriptExpDemo
{
    public partial class MainWindow : Window
    {
        
        /// <summary>
        /// The _process
        /// </summary>
        private Process _process;
        
        /// <summary>
        /// Initializes a new instance of the <see cref="MainWindow"/> class.
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Starts the process asynchronous.
        /// </summary>
        /// <param name="FileName">Name of the file.</param>
        /// <param name="Arguments">The arguments.</param>
        public void StartProcessAsync(string FileName, string Arguments)
        {
            _process = new Process
            {
                EnableRaisingEvents = true,
                StartInfo =
                {
                    FileName = FileName,
                    Arguments = Arguments,
                    CreateNoWindow = true,
                    RedirectStandardError = true,
                    RedirectStandardOutput = true,
                    RedirectStandardInput = true,
                    UseShellExecute = false,
                    LoadUserProfile = true
                },
            };
                _process.OutputDataReceived += OnOutputLineReceived;
                _process.Start();
                _process.BeginOutputReadLine();
        }

        /// <summary>
        /// Called when [output line received].
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="DataReceivedEventArgs"/> instance containing the event data.</param>
        public void OnOutputLineReceived(object sender, DataReceivedEventArgs e)
        {
            if (e.Data != null)
            {
                Application.Current.Dispatcher.Invoke(
              DispatcherPriority.Send,
              new Action(
                  delegate()
                  {
                      ResultBox.AppendText(e.Data + "\n");
                  }));
            }
        }
        
        /// <summary>
        /// Handles the Click event of the StartBtn control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private void StartBtn_Click(object sender, RoutedEventArgs e)
        {
            string FileName = @"C:\Python27\python.exe";
            string Arguments =   @"E:\Test.py";
            StartProcessAsync(FileName, Arguments);
        }
    }
}